DisplayablePath.display\_filename\_prefix\_middle
=================================================

.. currentmodule:: ams.utils.paths

.. autoattribute:: DisplayablePath.display_filename_prefix_middle